@@ -114,11 +114,12 @@ operation_done (SeahorseOperation *operation, SeahorseWidget *swidget)
         if (err) {
             operation_progress (operation, err->message, 0.0, swidget);
             g_error_free (err);
-            return;
         }
+    } else {
+	    operation_progress (operation, "", 0.0, swidget);
     }
     
-    operation_progress (operation, "", 0.0, swidget);
+    g_signal_handlers_disconnect_by_func (swidget, disconnect_progress, operation);
     g_object_set_data (G_OBJECT (swidget), "operation", NULL);
 }
 
@@ -127,7 +128,6 @@ disconnect_progress (SeahorseWidget *widget, SeahorseOperation *op)
 {
     g_signal_handlers_disconnect_by_func (op, operation_progress, widget);
     g_signal_handlers_disconnect_by_func (op, operation_done, widget);
-    g_signal_handlers_disconnect_by_func (widget, disconnect_progress, op);
 }
 
 void 
@@ -270,7 +270,10 @@ progress_show (SeahorseOperation *operation)
     /* Release our reference on the operation when this window is destroyed */    
     g_object_set_data_full (G_OBJECT (swidget), "operation", operation, 
                             (GDestroyNotify)g_object_unref);    
-        
+
+    w = glade_xml_get_widget (swidget->xml, swidget->name);
+    gtk_window_move (GTK_WINDOW (w), 10, 10);
+
     /* Setup the title */
     title = (const gchar*)g_object_get_data (G_OBJECT (operation), "progress-title");
     if (title) {
@@ -319,7 +322,7 @@ seahorse_progress_show (SeahorseOperation *operation, const gchar *title,
     
     /* Show the progress, after one second */
     if (delayed)
-        g_timeout_add (1000, (GSourceFunc)progress_show, operation);
+        g_timeout_add_seconds (1, (GSourceFunc)progress_show, operation);
     
     /* Right away */
     else
