@@ -57,17 +57,41 @@ G_DEFINE_TYPE (SeahorseKeyserverResults, seahorse_keyserver_results, SEAHORSE_TY
 static gboolean 
 on_filter_objects (SeahorseObject *obj, SeahorseKeyserverResults *self) 
 {
-	gboolean ret;
-	char* name;
+	const gchar *match;
+	gboolean ret = FALSE;
+	gchar* value;
+	gsize n_value, n_match;
 
 	g_return_val_if_fail (SEAHORSE_IS_KEYSERVER_RESULTS (self), FALSE);
 	g_return_val_if_fail (SEAHORSE_IS_OBJECT (obj), FALSE);
-	if (g_utf8_strlen (self->pv->search_string, -1) == 0)
-		return TRUE;
 
-	name = g_utf8_casefold (seahorse_object_get_label (obj), -1);
-	ret = strstr (name, self->pv->search_string) != NULL;
-	g_free (name);
+	match = self->pv->search_string;
+	if (g_utf8_strlen (match, -1) == 0)
+		ret = TRUE;
+
+	/* Match against the label */
+	if (ret != TRUE) {
+		value = g_utf8_casefold (seahorse_object_get_label (obj), -1);
+		ret = strstr (value, match) != NULL;
+		g_free (value);
+	}
+	
+	/* Match against the key identifier */
+	if (ret != TRUE) {
+		if (strncmp (match, "0x", 2) == 0)
+			match += 2;
+		value = g_utf8_casefold (seahorse_object_get_identifier (obj), -1);
+		
+		/* Only compare as many bytes as exist in the key id */
+		n_value = strlen (value);
+		n_match = strlen (match);
+		if (n_value > n_match)
+			match += (n_value - n_match);
+		ret = strstr (value, match) != NULL;
+		
+		g_free (value);
+	}
+	
 	return ret;
 }
 
@@ -219,7 +243,7 @@ on_delete_event (GtkWidget* widget, GdkEvent* event, SeahorseKeyserverResults* s
 
 static const GtkActionEntry GENERAL_ENTRIES[] = {
 	{ "remote-menu", NULL, N_("_Remote") }, 
-	{ "app-close", GTK_STOCK_CLOSE, N_("_Close"), "<control>W", 
+	{ "app-close", GTK_STOCK_CLOSE, NULL, "<control>W", 
 	  N_("Close this window"), G_CALLBACK (on_app_close) }, 
 	{ "view-expand-all", GTK_STOCK_ADD, N_("_Expand All"), NULL, 
 	  N_("Expand all listings"), G_CALLBACK (on_view_expand_all) }, 
