@@ -192,10 +192,11 @@ static const GtkActionEntry UI_ENTRIES[] = {
 	{ "edit-menu", NULL, N_("_Edit") },
 	{ "view-menu", NULL, N_("_View") },
 	{ "help-menu", NULL, N_("_Help") },
-	
+#ifdef  WITH_KEYSERVER || WITH_SHARING
 	{ "app-preferences", GTK_STOCK_PREFERENCES, N_("Prefere_nces"), NULL,
 	  N_("Change preferences for this program"), G_CALLBACK (on_app_preferences) },
-	{ "app-about", "gtk-about", N_("_About"), NULL, 
+#endif
+	{ "app-about", GTK_STOCK_ABOUT, NULL, NULL, 
 	  N_("About this program"), G_CALLBACK (on_app_about) }, 
 	{ "help-show", GTK_STOCK_HELP, N_("_Contents"), "F1",
 	  N_("Show Seahorse help"), G_CALLBACK (on_help_show) } 
@@ -356,6 +357,7 @@ on_copy_complete (SeahorseOperation* op, SeahorseViewer* self)
 
 	board = gtk_clipboard_get (atom);
 	gtk_clipboard_set_text (board, text, (gint)size);
+	/* Translators: "Copied" is a verb (used as a status indicator), not an adjective for the word "keys" */
 	seahorse_viewer_set_status (self, _ ("Copied keys"));
 }
 
@@ -490,16 +492,16 @@ show_properties_for_selected (SeahorseViewer *self, SeahorseCommands *commands,
 }
 		
 static const GtkActionEntry KEY_ENTRIES[] = {
-	{ "show-properties", GTK_STOCK_PROPERTIES, N_("P_roperties"), NULL,
+	{ "show-properties", GTK_STOCK_PROPERTIES, NULL, NULL,
 	  N_("Show properties"), G_CALLBACK (on_key_properties) },
-	{ "edit-delete", GTK_STOCK_DELETE, N_("_Delete"), NULL,
+	{ "edit-delete", GTK_STOCK_DELETE, NC_("This text refers to deleting an item from its type's backing store.", "_Delete"), NULL,
 	  N_("Delete selected items"), G_CALLBACK (on_key_delete) }
 };
 
 static const GtkActionEntry EXPORT_ENTRIES[] = {
 	{ "file-export", GTK_STOCK_SAVE_AS, N_("E_xport..."), NULL,
 	  N_("Export to a file"), G_CALLBACK (on_key_export_file) },
-	{ "edit-export-clipboard", GTK_STOCK_COPY, N_("_Copy"), "<control>C",
+	{ "edit-export-clipboard", GTK_STOCK_COPY, NULL, "<control>C",
 	  N_("Copy to the clipboard"), G_CALLBACK (on_key_export_clipboard) }
 };
 		
@@ -653,7 +655,7 @@ seahorse_viewer_constructor (GType type, guint n_props, GObjectConstructParam *p
 		/* Setup the commands */
 		types = seahorse_registry_object_types (seahorse_registry_get (), "commands", NULL, NULL);
 		for (l = types; l; l = g_list_next (l)) {
-			GType typ = GPOINTER_TO_INT (l->data);
+			GType typ = GPOINTER_TO_SIZE (l->data);
 			SeahorseCommands *commands;
 			
 			commands = g_object_new (typ, "view", self, NULL);
